@@ -4,6 +4,7 @@ Find the conf.py files specified in sources
 import copy
 import importlib
 import os.path
+from typing import Any
 from typing import Dict
 from typing import List
 from typing import Tuple
@@ -28,23 +29,54 @@ def load(hub, sources: List[str], dyne_names: List[str], cli: str):
     dnames = set(dyne_names)
     for source in sources:
         dnames.update(raw[source]["DYNE"].keys())
+    hub.config.dirs.resolve_sources(dnames, raw)
     for name in dnames:
-        if name in dyne:
-            if name not in raw:
-                raw[name] = {"CONFIG": {}, "CLI_CONFIG": {}}
-            dyne_data = dyne[name]
-            if "CONFIG" in dyne_data:
-                dyne_data, config_draw = hub.config.dirs.parse_config(dyne_data, cli)
-                dict_tools.update.update(raw[cli]["CONFIG"], config_draw)
-            if "CLI_CONFIG" in dyne_data:
-                cli_draw = hub.config.dirs.parse_cli(dyne_data, cli)
-                dict_tools.update.update(raw[cli]["CLI_CONFIG"], cli_draw)
-            if "SUBCOMMANDS" in dyne_data:
-                subcmd_draw = hub.config.dirs.parse_subcommand(dyne_data, cli)
-                dict_tools.update.update(raw[cli]["SUBCOMMANDS"], subcmd_draw)
+        if name not in dyne:
+            continue
+        if name not in raw:
+            raw[name] = {"CONFIG": {}, "CLI_CONFIG": {}}
+        dyne_data = dyne[name]
+        dyne_data["name"] = name
+        if "CONFIG" in dyne_data:
+            dyne_data, config_draw = hub.config.dirs.parse_config(dyne_data, cli)
+            for new_dyne, new_dyne_data in config_draw.items():
+                if new_dyne not in raw:
+                    raw[new_dyne] = {}
+                if "CONFIG" not in raw[new_dyne]:
+                    raw[new_dyne]["CONFIG"] = {}
+                dict_tools.update.update(raw[new_dyne]["CONFIG"], config_draw[new_dyne])
+        if "CLI_CONFIG" in dyne_data:
+            cli_draw = hub.config.dirs.parse_cli(dyne_data, cli)
+            dict_tools.update.update(raw[cli]["CLI_CONFIG"], cli_draw)
+        if "SUBCOMMANDS" in dyne_data:
+            subcmd_draw = hub.config.dirs.parse_subcommand(dyne_data, cli)
+            dict_tools.update.update(raw[cli]["SUBCOMMANDS"], subcmd_draw)
     return raw
 
 
+def resolve_sources(hub, dnames: List[str], raw_cli: Dict[str, Any]):
+    """
+    If a cli opt defines a "source", then update the source defaults with the new values
+    """
+    for name in dnames:
+        if name not in raw_cli:
+            continue
+        dyne_config = copy.deepcopy(raw_cli[name].get("CONFIG", {}))
+        if not dyne_config:
+            continue
+
+        for opt_name, opt_data in dyne_config.items():
+            source = opt_data.get("source")
+            if not source:
+                continue
+            # Remove the option from it's parent and add it to the config of the source
+            raw_cli[name]["CONFIG"].pop(opt_name)
+            if opt_name in raw_cli[source]["CONFIG"]:
+                raw_cli[source]["CONFIG"][opt_name].update(opt_data)
+            else:
+                raw_cli[source]["CONFIG"][opt_name] = opt_data
+
+
 def find_configs(hub, sources: List[str]):
     raw = {}
     for source in sources:
@@ -75,14 +107,20 @@ def parse_config(hub, dyne_data: Dict[str, Dict], cli: str) -> Tuple[Dict, Dict]
         new_dyne = val.get("dyne")
         if new_dyne == "__cli__":
             new_dyne = cli
-        if new_dyne:
-            val["source"] = new_dyne
-            config_draw[key] = val
-            if (
-                key in dyne_data.get("CLI_CONFIG", {})
-                and "dyne" not in dyne_data["CLI_CONFIG"][key]
-            ):
-                dyne_data["CLI_CONFIG"][key]["dyne"] = new_dyne
+
+        if not new_dyne:
+            continue
+
+        if new_dyne not in config_draw:
+            config_draw[new_dyne] = {}
+
+        val["source"] = new_dyne
+        config_draw[new_dyne][key] = val
+        if (
+            key in dyne_data.get("CLI_CONFIG", {})
+            and "dyne" not in dyne_data["CLI_CONFIG"][key]
+        ):
+            dyne_data["CLI_CONFIG"][key]["dyne"] = new_dyne
     return dyne_data, config_draw
 
 
