@@ -20,6 +20,7 @@ def setup(hub, conf):
     ch.setLevel(hub.log.INT_LEVEL)
     ch.setFormatter(cf)
     root.addHandler(ch)
+    hub.log.handlers.addHandler(ch)
 
     ff = logging.Formatter(fmt=conf["log_fmt_logfile"], datefmt=conf["log_datefmt"])
     _, kwargs = hub.render.cli.args(conf["log_handler_options"])
@@ -27,3 +28,4 @@ def setup(hub, conf):
     fh.setLevel(hub.log.INT_LEVEL)
     fh.setFormatter(ff)
     root.addHandler(fh)
+    hub.log.handlers.addHandler(fh)
