@@ -26,6 +26,7 @@ def setup(hub, conf):
     ch.setLevel(hub.log.INT_LEVEL)
     ch.setFormatter(cf)
     root.addHandler(ch)
+    hub.log.handlers.addHandler(ch)
 
     _, kwargs = hub.render.cli.args(conf["log_handler_options"])
     ff = logging.Formatter(
@@ -42,3 +43,4 @@ def setup(hub, conf):
     fh.setLevel(hub.log.INT_LEVEL)
     fh.setFormatter(ff)
     root.addHandler(fh)
+    hub.log.handlers.addHandler(fh)
