@@ -7,7 +7,7 @@ __virtualname__ = "json"
 
 
 def __virtual__(hub):
-    return True
+    return (True,)
 
 
 def load(hub, path):
